@@ -136,11 +136,11 @@ def progress_until_fewer(futures, cores, factor, out_func, system_stats, system_
             elapsed = time.time() - t0
 
         print_nums = False
-        if elapsed < 0.8:
+        if elapsed < 0.8:  # pragma: no cover
             print('something bad happened in ray.wait, normally it takes 2.0 seconds, but it took', elapsed, file=sys.stderr)
             print_nums = True
 
-        if len(futures) != len(done) + len(pending):
+        if len(futures) != len(done) + len(pending):  # pragma: no cover
             print('something bad happened in ray.wait, counts do not add up:')
             print_nums = True
 
@@ -153,7 +153,7 @@ def progress_until_fewer(futures, cores, factor, out_func, system_stats, system_
         futures = pending
 
         if len(done):
-            if verbose and len(done) > 100:
+            if verbose and len(done) > 100:  # pragma: no cover
                 print('surprised to see {} psets done at once'.format(len(done)), file=sys.stderr)
                 sys.stderr.flush()
             for ret in done:
@@ -197,7 +197,7 @@ def map(func, psets, out_func=None, user_kwargs=None, chdir=None, outfile=None,
 
     # XXX temporarily diabled for Pandas
     #factor = check_serialized_size((func, worker_system_kwargs, user_kwargs, psets[0]), factor=1.2)
-    factor = 1.2
+    factor = 2.4
 
     # temporary: this works in ray map calls, but check serialize raises on it
     if 'raise_in_wrapper' in system_kwargs:
@@ -255,4 +255,9 @@ def map(func, psets, out_func=None, user_kwargs=None, chdir=None, outfile=None,
     system_stats.print_percentiles(name)
     missing = list(system_kwargs['pset_ids'].values())
 
-    return MapResults(system_kwargs.get('results', None), missing, system_kwargs['progress'], system_stats)
+    if 'results' in system_kwargs:
+        results = system_kwargs['results'].finalize()
+    else:
+        results = None
+
+    return MapResults(results, missing, system_kwargs['progress'], system_stats)
