@@ -13,7 +13,7 @@ GIGABYTE=1000000000  # close enough
 ray start --head --redis-port=$PORT --redis-password=$REDIS_PASSWORD --memory $GIGABYTE --object-store-memory $GIGABYTE --redis-max-memory $GIGABYTE
 
 if [ ! -z "$COVERAGE" ]; then
-    COVERAGE="--cov-report= --cov-append --cov paramsurvey -v -v"
+    COVERAGE="--cov-report= --cov-append --cov-branch --cov paramsurvey -v -v"
 fi
 
 # in order to find both the uninstalled paramsurvey and our test program,
