@@ -1,5 +1,6 @@
 from collections import OrderedDict
 import sys
+import pytest
 
 import pandas as pd
 import numpy as np
@@ -7,6 +8,29 @@ import numpy as np
 import paramsurvey.params
 
 
+def test__coerce_to_category():
+    # always fires, unless the types don't work out
+    # does not crash with weird datatypes
+    # returns the same thing if doesn't fire
+
+    s1 = pd.Series(range(10))
+    s2 = paramsurvey.params._coerce_to_category(s1)
+    assert s2.dtype == 'category'
+
+
+def test__infer_category():
+    s1 = pd.Series(range(10))
+    s2 = paramsurvey.params._infer_category(s1)
+    try:
+        assert s2.dtype != 'category'
+    except TypeError:  # oh, pandas
+        assert True
+
+    s1 = pd.Series(range(1000))
+    s2 = paramsurvey.params._coerce_to_category(s1)
+    assert s2.dtype == 'category'
+
+
 def test_product():
     df1 = pd.DataFrame({'col1': [1, 2]})
     df2 = pd.DataFrame({'col2': [3, 4]})
@@ -14,6 +38,7 @@ def test_product():
 
     df = paramsurvey.params.product(df1, df2, df3)
     assert len(df) == 8
+    assert df['col1'].dtype == 'category'
 
     nuniques = df.nunique('rows')
     assert np.array_equal(nuniques.values, np.array([2, 2, 2])), 'each column has 2 unique values'
@@ -64,10 +89,24 @@ def test_add_column():
     df = paramsurvey.params.product({'col1': [1, 2]}, {'col2': [3, 4]}, {'col3': [5, 6]})
     assert len(df) == 8
 
-    paramsurvey.params.add_column(df, 'col4', lambda row: row['col1'] + row['col2'])
+    df2 = paramsurvey.params.add_column(df, 'col4', lambda row: row['col1'] + row['col2'])
+
+    assert len(df2) == 8
+    assert df2['col4'].to_numpy().sum() == (1+2)*4 + (3+4)*4
+
+    df3 = paramsurvey.params.add_column(df, 'col4', lambda row: row['col1'] + row['col2'], infer_category=False)
+    assert df3.equals(df2)  # infer not called
+
+    df = pd.DataFrame([{'a': 0}] * 1000)
+    df4 = paramsurvey.params.add_column(df, 'col4', lambda row: 0)
+    assert df4['col4'].dtype == 'category'
+
+    df4 = paramsurvey.params.add_column(df, 'col4', lambda row: 0, infer_category=False)
+    try:
+        assert df4['col4'].dtype != 'category'
+    except TypeError:  # oh, pandas
+        pass
 
-    assert len(df) == 8
-    assert df['col4'].to_numpy().sum() == (1+2)*4 + (3+4)*4
 
 
 def params(m, n):
@@ -107,3 +146,6 @@ def test_param_quirks():
     # unhashable type 'list' will be inefficient but shouldn't crash
     psets = paramsurvey.params.product({'a': [[1], [2], [3]]})
     assert len(psets) == 3
+    with pytest.raises(TypeError):
+        # why does this assert a type error?
+        assert psets['a'].dtype != 'category'
